@@ -107,7 +107,7 @@ services_t *services_load()
 	{"linuxconf", 98, "linuxconf"},\
 	{"metagram", 99, "Metagram Relay"},\
 	{"newacct", 100, "[unauthorized use]"},\
-	{"hostname", 101, "hostnames NIC Host Name Server"},\
+	{"hostname", 101, "hostnames NIS Host Name Server"},\
 	{"iso-tsap", 102, "tsap ISO-TSAP Class 0"},\
 	{"gppitnp", 103, "Genesis Point-to-Point Trans Net, or x400 ISO Email"},\
 	{"acr-nema", 104, "ACR-NEMA Digital Imag. & Comm. 300"},\
