@@ -6,6 +6,6 @@
 #include "gps.h"
 #include "route.h"
 
-arp_elt *get_src_ip_list(netdev *nd, u_int16_t pingport, int rseed, int *nbip, u_int32_t dstip);
+struct arp_elt *get_src_ip_list(netdev *nd, u_int16_t pingport, int *nbip, u_int32_t dstip);
 
 #endif
